@@ -27,7 +27,7 @@ The output format of umls-similarity.pl will work here because it
 extracts the CUIs from the paranthesis, so no worries. If you are 
 not using the CUI format or a umls-similarity.pl output file though, 
 use the --word option described below. 
-
+  
 =head1 Optional Arguments:
 
 Displays the quick summary of program options.
@@ -212,10 +212,12 @@ while(<X>) {
 	$c2 = $1;
     }
 
+ 
+    if($score == -1.0000) { $xnegative++; next; }
+
     $xtotal++;
-    if($score < 0) { $xnegative++; next; }
-    
-    $term = "$c1 $c2";
+  
+    $term = "$c1 $c2"; 
     push @{$xhash{$score}}, $term;
     $xlist{$term}++;
 }
@@ -224,8 +226,11 @@ while(<Y>) {
     chomp;
     my ($score, $t1, $t2) = split/<>/;
 
+
     my $c1 = ""; my $c2 = "";
     if(defined $opt_word) { 
+	$t1=~s/\(C[0-9]+\)//g; 
+	$t2=~s/\(C[0-9]+\)//g; 
 	$c1 = $t1; $c2 = $t2;
     }
     else {
@@ -236,10 +241,12 @@ while(<Y>) {
 	$c2 = $1;
     }
 
-    $ytotal++;
-    if($score < 0) { $ynegative++; next; }
     
-    $term = "$c1 $c2";
+    if($score == -1.0000) { $ynegative++; next; }
+
+    $ytotal++;
+
+    $term = "$c1 $c2"; 
     push @{$yhash{$score}}, $term;
     $ylist{$term}++;
 }
@@ -297,11 +304,11 @@ foreach my $score (sort {$b<=>$a} keys %yhash) {
     } 
 }
 
+print STDERR "$xcount : $ycount\n";
 
 $xmean = $xmean/$xcount;
 $ymean = $ymean/$ycount;
 
-
 my $numerator = 0;
 my $xdenom = 0;
 my $ydenom = 0;
@@ -323,6 +330,7 @@ if($denominator <= 0) {
     print STDERR "Files do not contain similar ngrams.\n";
     exit;
 }
+
 my $pearsons = $numerator / $denominator;
 
 my $score = sprintf $floatformat, $pearsons;
@@ -334,15 +342,15 @@ my $N = $yN;
 if($xN < $yN){ $N = $xN; }
 
 #  calculate tscore 
-my $t = $score/(sqrt( (1-$score**2)/($N-2) ));
+#my $t = $score/(sqrt( (1-$score**2)/($N-2) ));
 
 #  calculate z-score
-my $Fr = .5 * log((1+$score)/(1-$score));
-my $z  = sqrt(($N-3)/1.06) * $Fr;
+#my $Fr = .5 * log((1+$score)/(1-$score));
+#my $z  = sqrt(($N-3)/1.06) * $Fr;
 
 print "Spearman's Rank Correlation: $score "; 
 if(defined $opt_N)     { print "(N: $N) "; }
-if(defined $opt_t)     { print "(t: $t) "; }
+#if(defined $opt_t)     { print "(t: $t) "; }
 print "\n";
 
 ##############################################################################
@@ -387,7 +395,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: spearmans.pl,v 1.12 2013/02/15 22:51:39 btmcinnes Exp $';
+    print '$Id: spearmans.pl,v 1.13 2015/06/23 13:33:06 btmcinnes Exp $';
     print "\nCopyright (c) 2009-2011, Ted Pedersen & Bridget McInnes\n";
 }
 
