@@ -963,10 +963,10 @@ sub loadMeasures {
     }    
     #  loading the module implementing closeness
     #  modification of wup
-    if($measure eq "closeness") {
-	use UMLS::Similarity::closeness;	
-	$meas = UMLS::Similarity::closeness->new($umls);
-    }    
+    #if($measure eq "closeness") {
+    #use UMLS::Similarity::closeness;	
+    #$meas = UMLS::Similarity::closeness->new($umls);
+    #}    
     #  loading the module implementing the Zhong
     #  et al (2002) measure
     if($measure eq "zhong") {
@@ -1712,7 +1712,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: umls-similarity.pl,v 1.112 2015/06/23 14:57:59 btmcinnes Exp $';
+    print '$Id: umls-similarity.pl,v 1.113 2015/06/24 19:25:05 btmcinnes Exp $';
     print "\nCopyright (c) 2008-2011, Ted Pedersen & Bridget McInnes\n";
 }
 
